@@ -25,71 +25,71 @@ from ceilometer import service as ceilometer_service
 from ceilometer.tests import base as test
 
 NOTIFICATION = {
-    'event_type': u'test.create',
-    'metadata': {'timestamp': u'2015-06-19T09:19:35.786893',
-                 'message_id': u'939823de-c242-45a2-a399-083f4d6a8c3e'},
-    'payload': {u'user_id': u'e1d870e51c7340cb9d555b15cbfcaec2',
-                u'resource_id': u'bea70e51c7340cb9d555b15cbfcaec23',
-                u'timestamp': u'2015-06-19T09:19:35.785330',
-                u'created_at': u'2015-06-19T09:25:35.785330',
-                u'launched_at': u'2015-06-19T09:25:40.785330',
-                u'message_signature': u'fake_signature1',
-                u'resource_metadata': {u'foo': u'bar'},
-                u'source': u'30be1fc9a03c4e94ab05c403a8a377f2: openstack',
-                u'volume': 1.0,
-                u'project_id': u'30be1fc9a03c4e94ab05c403a8a377f2',
+    'event_type': 'test.create',
+    'metadata': {'timestamp': '2015-06-19T09:19:35.786893',
+                 'message_id': '939823de-c242-45a2-a399-083f4d6a8c3e'},
+    'payload': {'user_id': 'e1d870e51c7340cb9d555b15cbfcaec2',
+                'resource_id': 'bea70e51c7340cb9d555b15cbfcaec23',
+                'timestamp': '2015-06-19T09:19:35.785330',
+                'created_at': '2015-06-19T09:25:35.785330',
+                'launched_at': '2015-06-19T09:25:40.785330',
+                'message_signature': 'fake_signature1',
+                'resource_metadata': {'foo': 'bar'},
+                'source': '30be1fc9a03c4e94ab05c403a8a377f2: openstack',
+                'volume': 1.0,
+                'project_id': '30be1fc9a03c4e94ab05c403a8a377f2',
                 },
-    'ctxt': {u'tenant': u'30be1fc9a03c4e94ab05c403a8a377f2',
-             u'request_id': u'req-da91b4bf-d2b5-43ae-8b66-c7752e72726d',
-             u'user': u'e1d870e51c7340cb9d555b15cbfcaec2'},
+    'ctxt': {'tenant': '30be1fc9a03c4e94ab05c403a8a377f2',
+             'request_id': 'req-da91b4bf-d2b5-43ae-8b66-c7752e72726d',
+             'user': 'e1d870e51c7340cb9d555b15cbfcaec2'},
     'publisher_id': "foo123"
 }
 
 USER_META = {
-    'event_type': u'test.create',
-    'metadata': {'timestamp': u'2015-06-19T09:19:35.786893',
-                 'message_id': u'939823de-c242-45a2-a399-083f4d6a8c3e'},
-    'payload': {u'user_id': u'e1d870e51c7340cb9d555b15cbfcaec2',
-                u'resource_id': u'bea70e51c7340cb9d555b15cbfcaec23',
-                u'timestamp': u'2015-06-19T09:19:35.785330',
-                u'created_at': u'2015-06-19T09:25:35.785330',
-                u'launched_at': u'2015-06-19T09:25:40.785330',
-                u'message_signature': u'fake_signature1',
-                u'resource_metadata': {u'foo': u'bar'},
-                u'source': u'30be1fc9a03c4e94ab05c403a8a377f2: openstack',
-                u'volume': 1.0,
-                u'project_id': u'30be1fc9a03c4e94ab05c403a8a377f2',
-                u'metadata': {u'metering.xyz': u'abc', u'ignore': u'this'},
+    'event_type': 'test.create',
+    'metadata': {'timestamp': '2015-06-19T09:19:35.786893',
+                 'message_id': '939823de-c242-45a2-a399-083f4d6a8c3e'},
+    'payload': {'user_id': 'e1d870e51c7340cb9d555b15cbfcaec2',
+                'resource_id': 'bea70e51c7340cb9d555b15cbfcaec23',
+                'timestamp': '2015-06-19T09:19:35.785330',
+                'created_at': '2015-06-19T09:25:35.785330',
+                'launched_at': '2015-06-19T09:25:40.785330',
+                'message_signature': 'fake_signature1',
+                'resource_metadata': {'foo': 'bar'},
+                'source': '30be1fc9a03c4e94ab05c403a8a377f2: openstack',
+                'volume': 1.0,
+                'project_id': '30be1fc9a03c4e94ab05c403a8a377f2',
+                'metadata': {'metering.xyz': 'abc', 'ignore': 'this'},
                 },
-    'ctxt': {u'tenant': u'30be1fc9a03c4e94ab05c403a8a377f2',
-             u'request_id': u'req-da91b4bf-d2b5-43ae-8b66-c7752e72726d',
-             u'user': u'e1d870e51c7340cb9d555b15cbfcaec2'},
+    'ctxt': {'tenant': '30be1fc9a03c4e94ab05c403a8a377f2',
+             'request_id': 'req-da91b4bf-d2b5-43ae-8b66-c7752e72726d',
+             'user': 'e1d870e51c7340cb9d555b15cbfcaec2'},
     'publisher_id': "foo123"
 }
 
 MIDDLEWARE_EVENT = {
-    u'ctxt': {u'request_id': u'req-a8bfa89b-d28b-4b95-9e4b-7d7875275650',
-              u'quota_class': None,
-              u'service_catalog': [],
-              u'auth_token': None,
-              u'user_id': None,
-              u'is_admin': True,
-              u'user': None,
-              u'remote_address': None,
-              u'roles': [],
-              u'timestamp': u'2013-07-29T06:51:34.348091',
-              u'project_name': None,
-              u'read_deleted': u'no',
-              u'tenant': None,
-              u'instance_lock_checked': False,
-              u'project_id': None,
-              u'user_name': None},
-    u'event_type': u'objectstore.http.request',
-    u'publisher_id': u'ceilometermiddleware',
-    u'metadata': {u'message_id': u'6eccedba-120e-4db8-9735-2ad5f061e5ee',
-                  u'timestamp': u'2013-07-29T06:51:34.474815+00:00',
-                  u'_unique_id': u'0ee26117077648e18d88ac76e28a72e2'},
-    u'payload': {
+    'ctxt': {'request_id': 'req-a8bfa89b-d28b-4b95-9e4b-7d7875275650',
+             'quota_class': None,
+             'service_catalog': [],
+             'auth_token': None,
+             'user_id': None,
+             'is_admin': True,
+             'user': None,
+             'remote_address': None,
+             'roles': [],
+             'timestamp': '2013-07-29T06:51:34.348091',
+             'project_name': None,
+             'read_deleted': 'no',
+             'tenant': None,
+             'instance_lock_checked': False,
+             'project_id': None,
+             'user_name': None},
+    'event_type': 'objectstore.http.request',
+    'publisher_id': 'ceilometermiddleware',
+    'metadata': {'message_id': '6eccedba-120e-4db8-9735-2ad5f061e5ee',
+                  'timestamp': '2013-07-29T06:51:34.474815+00:00',
+                  '_unique_id': '0ee26117077648e18d88ac76e28a72e2'},
+    'payload': {
         'typeURI': 'http: //schemas.dmtf.org/cloud/audit/1.0/event',
         'eventTime': '2013-07-29T06:51:34.474815+00:00',
         'target': {
@@ -137,99 +137,103 @@ MIDDLEWARE_EVENT = {
 }
 
 FULL_MULTI_MSG = {
-    'event_type': u'full.sample',
+    'event_type': 'full.sample',
     'payload': [{
-                u'counter_name': u'instance1',
-                u'user_id': u'user1',
-                u'resource_id': u'res1',
-                u'counter_unit': u'ns',
-                u'counter_volume': 28.0,
-                u'project_id': u'proj1',
-                u'counter_type': u'gauge'
+                'counter_name': 'instance1',
+                'user_id': 'user1',
+                'user_name': 'test-resource',
+                'resource_id': 'res1',
+                'counter_unit': 'ns',
+                'counter_volume': 28.0,
+                'project_id': 'proj1',
+                'project_name': 'test-resource',
+                'counter_type': 'gauge'
                 },
                 {
-                u'counter_name': u'instance2',
-                u'user_id': u'user2',
-                u'resource_id': u'res2',
-                u'counter_unit': u'%',
-                u'counter_volume': 1.0,
-                u'project_id': u'proj2',
-                u'counter_type': u'delta'
+                'counter_name': 'instance2',
+                'user_id': 'user2',
+                'user_name': 'test-resource',
+                'resource_id': 'res2',
+                'counter_unit': '%',
+                'counter_volume': 1.0,
+                'project_id': 'proj2',
+                'project_name': 'test-resource',
+                'counter_type': 'delta'
                 }],
-    u'ctxt': {u'domain': None,
-              u'request_id': u'req-da91b4bf-d2b5-43ae-8b66-c7752e72726d',
-              u'auth_token': None,
-              u'read_only': False,
-              u'resource_uuid': None,
-              u'user_identity': u'fake_user_identity---',
-              u'show_deleted': False,
-              u'tenant': u'30be1fc9a03c4e94ab05c403a8a377f2',
-              u'is_admin': True,
-              u'project_domain': None,
-              u'user': u'e1d870e51c7340cb9d555b15cbfcaec2',
-              u'user_domain': None},
-    'publisher_id': u'ceilometer.api',
-    'metadata': {'message_id': u'939823de-c242-45a2-a399-083f4d6a8c3e',
-                 'timestamp': u'2015-06-19T09:19:35.786893'},
+    'ctxt': {'domain': None,
+             'request_id': 'req-da91b4bf-d2b5-43ae-8b66-c7752e72726d',
+             'auth_token': None,
+             'read_only': False,
+             'resource_uuid': None,
+             'user_identity': 'fake_user_identity---',
+             'show_deleted': False,
+             'tenant': '30be1fc9a03c4e94ab05c403a8a377f2',
+             'is_admin': True,
+             'project_domain': None,
+             'user': 'e1d870e51c7340cb9d555b15cbfcaec2',
+             'user_domain': None},
+    'publisher_id': 'ceilometer.api',
+    'metadata': {'message_id': '939823de-c242-45a2-a399-083f4d6a8c3e',
+                 'timestamp': '2015-06-19T09:19:35.786893'},
 }
 
 METRICS_UPDATE = {
-    u'event_type': u'compute.metrics.update',
-    u'payload': {
-        u'metrics': [
-            {'timestamp': u'2013-07-29T06:51:34.472416',
+    'event_type': 'compute.metrics.update',
+    'payload': {
+        'metrics': [
+            {'timestamp': '2013-07-29T06:51:34.472416',
              'name': 'cpu.frequency', 'value': 1600,
              'source': 'libvirt.LibvirtDriver'},
-            {'timestamp': u'2013-07-29T06:51:34.472416',
+            {'timestamp': '2013-07-29T06:51:34.472416',
              'name': 'cpu.user.time', 'value': 17421440000000,
              'source': 'libvirt.LibvirtDriver'},
-            {'timestamp': u'2013-07-29T06:51:34.472416',
+            {'timestamp': '2013-07-29T06:51:34.472416',
              'name': 'cpu.kernel.time', 'value': 7852600000000,
              'source': 'libvirt.LibvirtDriver'},
-            {'timestamp': u'2013-07-29T06:51:34.472416',
+            {'timestamp': '2013-07-29T06:51:34.472416',
              'name': 'cpu.idle.time', 'value': 1307374400000000,
              'source': 'libvirt.LibvirtDriver'},
-            {'timestamp': u'2013-07-29T06:51:34.472416',
+            {'timestamp': '2013-07-29T06:51:34.472416',
              'name': 'cpu.iowait.time', 'value': 11697470000000,
              'source': 'libvirt.LibvirtDriver'},
-            {'timestamp': u'2013-07-29T06:51:34.472416',
+            {'timestamp': '2013-07-29T06:51:34.472416',
              'name': 'cpu.user.percent', 'value': 0.012959045637294348,
              'source': 'libvirt.LibvirtDriver'},
-            {'timestamp': u'2013-07-29T06:51:34.472416',
+            {'timestamp': '2013-07-29T06:51:34.472416',
              'name': 'cpu.kernel.percent', 'value': 0.005841204961898534,
              'source': 'libvirt.LibvirtDriver'},
-            {'timestamp': u'2013-07-29T06:51:34.472416',
+            {'timestamp': '2013-07-29T06:51:34.472416',
              'name': 'cpu.idle.percent', 'value': 0.9724985141658965,
              'source': 'libvirt.LibvirtDriver'},
-            {'timestamp': u'2013-07-29T06:51:34.472416',
+            {'timestamp': '2013-07-29T06:51:34.472416',
              'name': 'cpu.iowait.percent', 'value': 0.008701235234910634,
              'source': 'libvirt.LibvirtDriver'},
-            {'timestamp': u'2013-07-29T06:51:34.472416',
+            {'timestamp': '2013-07-29T06:51:34.472416',
              'name': 'cpu.percent', 'value': 0.027501485834103515,
              'source': 'libvirt.LibvirtDriver'}],
-        u'nodename': u'tianst.sh.intel.com',
-        u'host': u'tianst',
-        u'host_id': u'10.0.1.1'},
-    u'publisher_id': u'compute.tianst.sh.intel.com',
-    u'metadata': {u'message_id': u'6eccedba-120e-4db8-9735-2ad5f061e5ee',
-                  u'timestamp': u'2013-07-29 06:51:34.474815',
-                  u'_unique_id': u'0ee26117077648e18d88ac76e28a72e2'},
-    u'ctxt': {u'request_id': u'req-a8bfa89b-d28b-4b95-9e4b-7d7875275650',
-              u'quota_class': None,
-              u'service_catalog': [],
-              u'auth_token': None,
-              u'user_id': None,
-              u'is_admin': True,
-              u'user': None,
-              u'remote_address': None,
-              u'roles': [],
-              u'timestamp': u'2013-07-29T06:51:34.348091',
-              u'project_name': None,
-              u'read_deleted': u'no',
-              u'tenant': None,
-              u'instance_lock_checked': False,
-              u'project_id': None,
-              u'user_name': None}
+        'nodename': 'tianst.sh.intel.com',
+        'host': 'tianst',
+        'host_id': '10.0.1.1'},
+    'publisher_id': 'compute.tianst.sh.intel.com',
+    'metadata': {'message_id': '6eccedba-120e-4db8-9735-2ad5f061e5ee',
+                 'timestamp': '2013-07-29 06:51:34.474815',
+                 '_unique_id': '0ee26117077648e18d88ac76e28a72e2'},
+    'ctxt': {'request_id': 'req-a8bfa89b-d28b-4b95-9e4b-7d7875275650',
+             'quota_class': None,
+             'service_catalog': [],
+             'auth_token': None,
+             'user_id': None,
+             'is_admin': True,
+             'user': None,
+             'remote_address': None,
+             'roles': [],
+             'timestamp': '2013-07-29T06:51:34.348091',
+             'project_name': None,
+             'read_deleted': 'no',
+             'tenant': None,
+             'instance_lock_checked': False,
+             'project_id': None,
+             'user_name': None}
 }
 
 
@@ -615,7 +619,16 @@ class TestMeterProcessing(test.BaseTestCase):
         c = list(self.handler.build_sample(event))
         self.assertEqual(0, len(c))
 
-    def test_multi_meter_payload_all_multi(self):
+    @mock.patch('ceilometer.cache_utils.resolve_uuid_from_cache')
+    def test_multi_meter_payload_all_multi(self, fake_cached_resource_name):
+
+        # return "test-resource" as the name of the user and project from cache
+        fake_cached_resource_name.return_value = "test-resource"
+
+        # expect user_name and project_name values to be set to "test-resource"
+        fake_user_name = "test-resource"
+        fake_project_name = "test-resource"
+
         cfg = yaml.dump(
             {'metric': [dict(name="$.payload.[*].counter_name",
                         event_type="full.sample",
@@ -640,6 +653,8 @@ class TestMeterProcessing(test.BaseTestCase):
             self.assertEqual(msg[idx]['resource_id'], s1['resource_id'])
             self.assertEqual(msg[idx]['project_id'], s1['project_id'])
             self.assertEqual(msg[idx]['user_id'], s1['user_id'])
+            self.assertEqual(fake_user_name, s1['user_name'])
+            self.assertEqual(fake_project_name, s1['project_name'])
 
     @mock.patch('ceilometer.meter.notifications.LOG')
     def test_multi_meter_payload_invalid_missing(self, LOG):
