@@ -137,8 +137,12 @@ function ceilometer_create_accounts {
 
 function install_gnocchi {
     echo_summary "Installing Gnocchi"
-    if [ $GNOCCHI_GIT_PATH ]; then
-        pip_install -e $GNOCCHI_GIT_PATH[redis,${DATABASE_TYPE},keystone] uwsgi
+    if use_library_from_git "gnocchi"; then
+        # we need to git clone manually to ensure that the git repo is added
+        # to the global git repo list and ensure its cloned as the current user
+        # not as root.
+        git_clone ${GNOCCHI_REPO} ${GNOCCHI_DIR} ${GNOCCHI_BRANCH}
+        pip_install -e ${GNOCCHI_DIR}[redis,${DATABASE_TYPE},keystone] uwsgi
     else
         pip_install gnocchi[redis,${DATABASE_TYPE},keystone] uwsgi
     fi
@@ -170,7 +174,7 @@ function configure_gnocchi {
     write_uwsgi_config "$GNOCCHI_UWSGI_FILE" "$CEILOMETER_BIN_DIR/gnocchi-api" "/metric"
 
     if [ -n "$GNOCCHI_COORDINATOR_URL" ]; then
-        iniset $GNOCCHI_CONF storage coordination_url "$GNOCCHI_COORDINATOR_URL"
+        iniset $GNOCCHI_CONF coordination_url "$GNOCCHI_COORDINATOR_URL"
     fi
 }
 
@@ -206,25 +210,14 @@ function _ceilometer_configure_cache_backend {
 # Set configuration for storage backend.
 function _ceilometer_configure_storage_backend {
     if [ "$CEILOMETER_BACKEND" = 'none' ] ; then
-        # It's ok for the backend to be 'none', if panko is enabled. We do not
-        # combine this condition with the outer if statement, so that the else
-        # clause below is not executed.
-        if ! is_service_enabled panko-api; then
-            echo_summary "All Ceilometer backends seems disabled, set \$CEILOMETER_BACKEND to select one."
-        fi
+        echo_summary "All Ceilometer backends seems disabled, set \$CEILOMETER_BACKEND to select one."
     elif [ "$CEILOMETER_BACKEND" = 'gnocchi' ] ; then
-        sed -i "s/gnocchi:\/\//gnocchi:\/\/?archive_policy=${GNOCCHI_ARCHIVE_POLICY}\&filter_project=gnocchi_swift/" $CEILOMETER_CONF_DIR/event_pipeline.yaml $CEILOMETER_CONF_DIR/pipeline.yaml
+        sed -i "s/gnocchi:\/\//gnocchi:\/\/?archive_policy=${GNOCCHI_ARCHIVE_POLICY}\&filter_project=service/" $CEILOMETER_CONF_DIR/event_pipeline.yaml $CEILOMETER_CONF_DIR/pipeline.yaml
         ! [[ $DEVSTACK_PLUGINS =~ 'gnocchi' ]] && configure_gnocchi
     else
         die $LINENO "Unable to configure unknown CEILOMETER_BACKEND $CEILOMETER_BACKEND"
     fi
 
-    # configure panko
-    if is_service_enabled panko-api; then
-        if ! grep -q 'panko' $CEILOMETER_CONF_DIR/event_pipeline.yaml ; then
-            echo '          - panko://' >> $CEILOMETER_CONF_DIR/event_pipeline.yaml
-        fi
-    fi
 }
 
 # Configure Ceilometer
